@@ -215,12 +215,12 @@
 #elif defined(MRN_MARIADB_P) && MYSQL_VERSION_ID >= 100000
 #  define mrn_init_alloc_root(root, name, block_size, pre_alloc_size, flags) \
   init_alloc_root(root, block_size, pre_alloc_size, flags)
-#elif MYSQL_VERSION_ID >= 50706
+#elif MYSQL_VERSION_ID >= 80027
 #  define mrn_init_alloc_root(root, name, block_size, pre_alloc_size, flags) \
-  init_alloc_root(mrn_memory_key, root, block_size, pre_alloc_size)
+  ::new ((void *)root) MEM_ROOT(mrn_memory_key, block_size)
 #else
 #  define mrn_init_alloc_root(root, name, block_size, pre_alloc_size, flags) \
-  init_alloc_root(root, block_size, pre_alloc_size)
+  init_alloc_root(mrn_memory_key, root, block_size, pre_alloc_size)
 #endif
 
 #if MYSQL_VERSION_ID < 100002 || !defined(MRN_MARIADB_P)
@@ -1031,3 +1031,9 @@ typedef uint mrn_srid;
 #  define MRN_MATCH_ITEM_FLAGS(match_item) \
   ((match_item)->flags)
 #endif
+
+#if MYSQL_VERSION_ID >= 80027 && !defined(MRN_MARIADB_P)
+#  define MRN_FREE_ROOT(root) (root)->Clear()
+#else
+#  define MRN_FREE_ROOT(root) free_root((root), MYF(0))
+#endif
